@@ -1,9 +1,9 @@
+from sail import cli, util
+
 import os, subprocess
 import click
 
-from . import util
-
-@click.command()
+@cli.command()
 @click.option('--nginx', is_flag=True)
 @click.option('--php', is_flag=True)
 @click.option('--nginx-access', is_flag=True)
@@ -12,7 +12,7 @@ from . import util
 @click.option('--follow', '-f', is_flag=True)
 @click.option('--lines', '-n', type=int)
 def logs(nginx, php, nginx_access, nginx_error, php_error, follow, lines):
-	'''Run a WP-CLI command on the production host'''
+	'''Query and follow logs from the production server'''
 	root = util.find_root()
 	sail_config = util.get_sail_config()
 
