@@ -1,9 +1,9 @@
+from sail import cli, util
+
 import os, subprocess
 import click
 
-from . import util
-
-@click.command()
+@cli.command()
 @click.option('--root', '--host', is_flag=True, help='Login to the host (not the container) as the root user')
 def ssh(root):
 	'''Open an interactive SSH shell to the production container or host'''
@@ -18,7 +18,6 @@ def ssh(root):
 
 	click.echo('Spawning an interactive SSH shell for %s.sailed.io' % sail_config['app_id'])
 
-	# TODO: Allow ssh-ing into the docker container by default, and to host with --host
 	os.execlp('ssh', 'ssh', '-t',
 		'-i', '%s/.sail/ssh.key' % root,
 		'-o', 'UserKnownHostsFile=%s/.sail/known_hosts' % root,
