@@ -1,9 +1,9 @@
+from sail import cli, util
+
 import os, subprocess
 import click, shlex
 
-from . import util
-
-@click.command(context_settings=dict(ignore_unknown_options=True))
+@cli.command(context_settings=dict(ignore_unknown_options=True))
 @click.argument('command', nargs=-1)
 def wp(command):
 	'''Run a WP-CLI command on the production host'''
@@ -12,7 +12,7 @@ def wp(command):
 
 	command = shlex.join(command)
 
-	click.echo('Spawning SSH and running WP-CLI on %s.sailed.io' % sail_config['app_id'])
+	click.echo('Spawning SSH and running WP-CLI on %s.sailed.io' % sail_config['app_id'], err=True)
 
 	os.execlp('ssh', 'ssh', '-t',
 		'-i', '%s/.sail/ssh.key' % root,
